---
title: "Getting a Handle on the Truth"
date: 2016-08-13T19:03:02Z
tags: ["truth","logic","realism","syntax","semantics"]
topics: ["philosophy"]
image: /img/truthometer.jpg
draft: false
---

> “[What is truth?](http://biblehub.com/john/18-38.htm)” ~ Pontius Pilate

This is an interesting and surprisingly difficult question. If you look in the [OED](http://www.oxforddictionaries.com/us/definition/american_english/truth), what you’ll find there are entirely circular and self-referential explanations: “*the quality or state of being true*“, ” *that which is true or in accordance with fact or reality*“, and “*a fact or belief that is accepted as true*“.

So, the poor souls that rely on the dictionary are left with, essentially, “truth is what’s true”, and “what’s true is what we agree are the facts of reality.” But what if we’re wrong and we still agree? Or worse, what if we disagree, but one of us is right? This can’t be the last word on this topic. What can we say with any confidence about truth, as such? To put it in the words of Bertrand Russell:

> “We may believe what is false as well as what is true. We know that on very many subjects different people hold different and incompatible opinions: hence some beliefs must be erroneous. Since erroneous beliefs are often held just as strongly as true beliefs, it becomes a difficult question how they are to be distinguished from true beliefs. How are we to know, in a given case, that our belief is not erroneous? This is a question of the very greatest difficulty, to which no completely satisfactory answer is possible. There is, however, a preliminary question which is rather less difficult, and that is: **What do we mean by truth and falsehood?**” — [The Problems of Philosophy](http://www.mohamedrabeea.com/books/book1_10174.pdf) (p. 77)

Thinking on the question a bit, I realized I’m not quite sure *what* I mean. So, I decided to take a brief look at what what philosophy has had to say on the subject over the centuries, to see if I might find something I’m willing to accede to, at least in the short term.

As Russell is careful to point out in the book I just referenced, any real understanding of truth must start first with understanding what knowledge is. But even this is tricky. I wanted to simply stipulate to the classical definition, in order to shorten this post. But what we find in the traditional definition of knowledge, is yet another circular reference: knowledge is [Justified True Belief](http://plato.stanford.edu/entries/knowledge-analysis/#TruCon). In other words, that which is *known* is that which satisfies all of the following three conditions:

1. It is believed
2. That belief is justified
3. That belief **is true**

For the sake of brevity, I’ll let the [Stanford encyclopedia](http://plato.stanford.edu/entries/knowledge-analysis/#KnoJusTruBel) explain these three conditions in detail, and I’ll set aside [common objections](https://en.wikipedia.org/wiki/Gettier_problem) to this formulation of knowledge for a later post. Nevertheless, in spite of Stanford’s assertion that “*the truth condition is largely uncontroversial*“, I think the fact that *truth* is present in the definition of knowledge is a serious problem for philosophy because it makes the two terms fundamentally dependent upon each other: *truth is that which is known is that which is the truth*.

As such, I find it hard to blame the dictionary for its circularity when it relies for its definitions on an academic discipline that can’t seem to provide a clear answer to this question. What’s more, I think it’s a little disingenuous for “serious” philosophers to scoff at Ayn Rand for her insistence on unjustified “axioms” like “[Existence Exists](http://aynrandlexicon.com/lexicon/primacy_of_existence_vs_primacy_of_consciousness.html)“, or to laugh at Christians who, facing no real alternative, rely on Jesus’ pronouncement that actually it is *he personally* who is “…*the way, the truth, and the life*…” ([John 14:6](http://biblehub.com/john/14-6.htm)).

To be completely clear, my aim here is not to argue that *there is no such thing as truth*, or that *we cannot know things* or *cannot justifiably claim to know the truth* — or worse, that we should just throw our hands up and simply declare it to be *whatever we want it to be*. To do so, I’d have to employ the very tools of thought that I’d be condemning. All I am suggesting is that maybe we’re not as sure as we think we are, and that maybe we need to rethink some of these fundamental questions.

### What Everyone Else Thinks

As one might expect, given what I have stated above, there are actually [numerous philosophical theories of truth](https://en.wikipedia.org/wiki/Truth). The most popular among them, the “[correspondence theory](http://www.iep.utm.edu/truth/#H3)“, offers the greatest appeal to common sense. This theory is probably where the OED gets it’s turn of phrase “in accordance with fact or reality”. The theory states that “*a proposition is true provided there exists a fact corresponding to it.*” But what does “correspondence” mean? And what, exactly, are facts? Russell makes a lot of hay on this second question, in his [own conception of correspondence](http://www.users.drew.edu/~jlenz/br-joachim-on-truth1.html#top). In short, this definition “works”, but it’s not entirely satisfying (as Russell notes in the above quote).

Some argue for something called “[coherence](http://www.iep.utm.edu/truth/#H5)“, in which each new statement is compared to a complete set of beliefs, and rejected if it does not “fit” within that collection. This theory seems to fail on two grounds: first, that it is not *necessary* for the collection of beliefs to have any relation to reality, and secondly, as [Russell again points out](http://plato.stanford.edu/entries/truth-coherence/#Cri), because of the first problem, there can be many equally “coherent” belief systems existing side by side. How do we know which one to choose? The problems point to a third problem, that I think also plagues the pragmatist, constructivist, and consensus theories of truth. Namely, that they all elevate mere *belief* to the ontological status of a fact, by virtue of some *ex post facto* rationale. What’s more, this equivocation seems to go unnoticed (or worse, dishonestly ignored) by the theories’ adherents.

### What I think

I find [Kant’s idea](http://www.philosophynews.com/post/2015/01/29/What-is-Truth.aspx) of the conjunction between the noumenal and phenomenal world somewhat compelling. Although, probably not for reasons Kant would approve. Science shows us that there is a reality that is outside the reach of the senses. Perhaps truth, then, is the extent to which we can apprehend these non-phenomenal parts of reality, and reconcile them with the phenomenal parts. Already, science has provided us with all sorts of tools for doing this (telescopes, microscopes, sensors, meters, etc.). If this is true (somewhat ironically), then the way to the truth is through scientific inquiry. This is certainly a different route to truth via science than the pragmatists propose, but I think the destination may be the same.

On the other hand, although I don’t quite understand his theory, [Alfred Tarsky](http://plato.stanford.edu/entries/truth/#TarTheTru)‘s emphasis on semantics got me to wondering.

I have heard truth described by some as a relationship between physical reality and conscious awareness. This is not quite the same thing as correspondence, because the focus here is not on the objects in the relation, but *the relation itself*. It’s an interesting idea, but I think this isn’t quite complete. Because, if conscious awareness of reality is all that is necessary for a “truth” relation, then beavers and ants and birds would be capable of apprehending the truth. Clearly, then, it must something more.

That difference is language. Truth is as much a *semantic* concept, as it is a *metaphysical* one. Like knowledge, the definition of truth is concerned with the objects of mind and reality, and primarily with the nature of the relationship between them. But what is it about the nature of this relation, that makes it *truth*? I think it is the *meaning we assign* to that relationship, and the *value discovered* in the contents of that relationship.

In short, truth is a kind of semantic value judgment of the perception of reality as it is apprehended, by a mind capable of apprehending and valuing. But what does this mean, in practice? Is this just another way of formulating correspondence? Not quite. Is it the same as claiming that the truth is whatever we want it to be? Not quite. Is it pragmatism in another suit of clothes? I don’t think so.

But I’m struggling to find the words necessary to develop the idea any further. And perhaps that’s a clue to the problem with all of these theories. Maybe the problem lies precisely with the fact that our language is woefully lacking, when it comes to the task of describing these sorts of relationships. This is why I am beginning to wonder if we don’t need a new language, or a new way of thinking, or of describing our thoughts, before we can properly answer this question.

```[Imported From exitingthecave.com on 1 December 2021]```
