---
title: "Is the Categorical Imperative Convincing?"
date: 2017-11-09T23:20:49Z
tags: ["kant","categorical imperative","moral logic"]
topics: ["philosophy"]
image: /img/immanuel-kant.jpg
draft: false
---

The following essay answers the question:

> Are you convinced by Kant’s argument that there are categorical as well as hypothetical imperatives?

This question is not asking us to evaluate whether the consequences of a system of bifurcated imperatives is preferable or not, or to judge whether such a system could “work”. Rather, it is asking whether Kant, in his Groundwork on the Metaphysics of Morals, supplied a convincing argument that two sorts of imperatives *exist*. In other words, this is a logical and an ontological question, not a normative one.

What does it mean for an imperative to “exist”? And what is an “imperative”, in an ontological sense? Kant seems to equivocate subtly on this point. In a few places, he wants to say it is a “command” or “rule” (i.e., that which we are obliged to obey). At others places, he wants it to mean “determinator” or “cause” (i.e., that which necessitates its effect). What’s worse, is that this variation in meaning doesn’t always correspond to his “laws of nature” and “laws of reason”, either.

To be fair, Kant needn’t have worked quite so hard to prove the existence of hypothetical imperatives. That there are causal determinants of our “inclinations” and behaviors (even if only probabilistic in nature), and that we have the cognitive capacity to recognize and manipulate them in pursuit of objects of desire, seems to me to be a simple matter of brute observable fact. Getting from that to a conception of a hypothetical imperative is a single movement of thought, as far as I can tell. E.g., “If I want to get to Oxford, then I will need to book a ticket on the train from Waterloo”. And, there are all manner of social and legal “rules” that we choose to follow on similar grounds, every day: “If you don’t want a ticket, you oughtn’t park in the red zones”. Thus, I think a convincing argument for hypothetical imperatives is not only unnecessary, it’s nearly a self-evident truth.

#### The Meat of the Matter

What Kant does need to prove, is that there are two categories of imperatives, and that the latter exist regardless of (in fact, in spite of) empirical experience. So, what does Kant mean, when he says that the Categorical Imperative exists? He lays out a rather explicit syllogistic argument for this in the middle of essay two. I’ll try to give it a fair summary, so that we can evaluated it together, here:

1 – Everything in nature works according to laws.
2 – Only rational beings can act according to the conception of laws (aka can have a will).
2a – the deduction of actions from principles requires reason.
2b – therefore, the will (the seat of action) is itself practical reason.
3 – If reason perfectly determines the will, then actions that are objectively necessary, are also subjectively necessary (i.e. necessarily good).
4 – Reason does not perfectly determine the will.
5 – If other determinants are subjective and conditional, then the will cannot accord necessarily with reason.
6 – If the will does not perfectly accord with reason, then actions which are objectively necessary, are subjectively contingent.
7 – If (6), then the determination of the will according to objective laws is obligation, not necessity.
8 – The will does not perfectly accord with reason.
9 – Therefore, the will is determined by a principles of reason, but not necessarily.

Kant then summarizes the whole argument, as such:

> …the conception of an objective principle that is obligatory is called a command of reason and its formula is an imperative. All imperatives are expressed by the word “ought” [or “shall”] and thereby indicate the relation of an objective law of reason to a will, which from its subjective constitution is not necessarily determined by it [because it is merely an obligation]…[^1]

Kant was well aware of Hume and his “is-ought” problem (see Kant’s remarks about being “awakened” by Hume, from his “dogmatic slumber”, in the Prolegomena). So, I think this passage in the middle of essay two was Kant’s attempt to answer Hume directly, on how to bridge the categorical gap between “is” and “ought”. The answer seems to be, that objects of reason, under certain conditions (logical necessity, and universalizability), become determinants of the will. But, because this process is not one of absolute necessity, there must be something by which it can take place contingently. Kant tries to outline this process in steps 5, 6, and 7 of the argument. However, implicit in these steps is the fact that Kant has already asserted one set of laws for nature, and another set of laws for reason (classic Platonic idealism, by the way). In other words, Kant is presupposing what he is trying to prove — that there are laws of reason which we are obliged to obey.

But even if I were to set aside this issue, there are yet several other problems I see with this argument, mainly at steps 2 and 2a. In attempting to explain what the will is, he asserts, “the deduction of actions from principles requires reason”. But, what does it mean to “deduce” an action? This seems to me, to be precisely the sleight-of-hand that Hume was talking about in the Treatise. Deduction is a formal means of deriving a truth from a series of propositions, one of which we might call the “conclusion”. An action, though, is neither true nor false. The propositional description can be, but it’s simply a non-sequitur, in the context of a proper deductive argument[^2] (e.g., “I drive the car”, or “He ran to the store”). Thus, neither can an imperative stand in its stead. Let’s take Kant’s false-promise example, to highlight my point:

1 – If I tell a lie, I will escape an immediate harm.
2 – If I tell the truth, I will suffer an immediate harm.
C – I tell the truth.

In this formulation, premise one and two are both weak. Firstly, both are hypothetical and would require empirical testing in order to assign a truth value to them (which makes them contingently true, by definition). Secondly, they’re completely independent of each other (in other words, there is nothing necessarily “leading” from premise one to premise two). I could leave either of them out of the argument, and it wouldn’t matter. Third, I could drop both premises, and (as pointed out above), the value of the so-called ‘conclusion’ would not be effected at all. It remains a description of some behavior, regardless of the premises. In other words, the conclusion is not actually a conclusion, but a free-floating descriptive proposition. At best, it’s a chronological terminus to a series of thoughts. But where’s the necessity in that?

Now, I will add an additional premise, in an attempt to bolster Kant’s case:

1 – If I tell a lie, I will escape an immediate harm.
2 – If I tell the truth, I will suffer an immediate harm.
3 – If everyone lied, making promises would become impossible.
C – I tell the truth.

Kant seems to think that this shows the truth of the Categorical Imperative (act only such that… etc), because lying cannot be universalized. But does it? Premise three, if true, would result in profoundly absurd consequences in practice, but that’s not the same thing as a logical contradiction. Even worse, it implies that consequences actually do matter. Yet, Kant has admitted earlier on that an argument from consequences cannot be obligatory (much less have any moral worth) because they are contingent, not necessary.

In other words, the test of universalizability itself is not clear to me. On the one hand, he seems to be saying (I can’t recall exactly where), that anything that is logically contradictory is not universalizable (this would be something akin to Socrates’ search for definitions, I suppose — which comes with a whole host of its own problems). On the other hand, as with the lying example, he seems to be suggesting that it’s the speculative consequences that make the test fail (also, it seems to me that whether the bad outcome takes place in one instance or all instances doesn’t matter because once it fails for one person, the fail light turns red by definition). In short: If the standard is a purely logical one, then the fact that the duty would oblige us to lie all the time isn’t enough to fail the test. If the standard is preference for certain outcomes (i.e., “lying all the time isn’t practicable/sensible”), then he’s making an appeal to consequences in the material sense, and has violated his own system.

In addition to all of the problems of the first syllogism applying just the same to this one, there is a much more damaging problem. What if we were to state the conclusion as an imperative? “I ought to tell the truth”. Immediately, we see David Hume poking his head out, and chiding us. Even if we had valid premises that were coherently connected, there is nothing that could get us from those descriptive statements of fact, to a conclusion constructed as an imperative to act. Kant seems to think that simply by hiding the normative language, we can escape having to justify the implicit presence of it. But the problem remains, all the same. Try as he might, Kant has not been able to wriggle his leg out of Hume’s bear trap.

Finally, the Categorical Imperative could itself be expressed as a hypothetical imperative.

“If you wish to do good, then you are never to act otherwise than so that you could also will that your maxim should become a universal law.”

Nothing in Kant’s essay suggests to me why this would be necessarily incorrect. In fact, I am suspicious that all Kant did was to drop the hypothetical language in order to hide the fact that the categorical imperative was not actually categorical at all (just as he did during the explication of deriving actions deductively from premises. Thus, I do not think that Kant has made a convincing argument to prove the existence of a Categorical Imperative, even if we grant him his hypothetical imperatives.

#### Final Thought…

I think there is something very deeply seductive about the notion of universal absolutes. In addition to the logical certitude they offer, there is also the promise of independence from the authority or will of others. If I can appeal to a feature of reality over which none of us has power or authority, as a rationale for my behaviour, I am counter-intuitively empowered to independent action, in spite of any approval or disapproval of others.

The problem is that universal absolutes are also, necessarily, so abstract they can never fully justify any particular “duty” to an action within the circumstances in which they arise (just see any of Kant’s practical examples of the Categorical Imperative or [read this essay](http://www.mesacc.edu/~davpy35701/text/kant-sup-right-to-lie.pdf) in which he is responding to someone who called him out on the problem of false promises, to see what I mean).

I think those of use who grew up in intensely authoritarian or strongly religious households may be especially susceptible to this sort of thinking. The black-and-white of logical absolutes, combined with the lever of escape from the power of overbearing parents, makes for a potent psychological seed-bed in which a love for Kantianism is likely to take root.

[^1]: Kant, Immanuel. Groundwork for the Metaphysics of Morals: With Linked Table of Contents. Dancing Unicorn Books. Kindle Edition. 
[^2]: To be fair, you could say that a description of action might be properly the conclusion of an inductive argument (e.g., “His keys are gone; his car is gone; therefore, he went to work”). But Kant is explicit that he is working from deduction here. 
