---
title: "The Justice of Market Outcomes"
date: 2019-12-12T11:48:41Z
tags: ["marxism","egalitarianism","redistribution","justice"]
topics: ["philosophy","economics"]
image: /img/starling-flock.jpg
draft: false
---

In any given exchange market (whether free or otherwise), goods and services are traded as a matter of course, in the pursuit of both individual and social goals. Those trades will result in substantive outcomes both for the individuals involved in trades, and more broadly for society as a whole. It has been suggested that some of those outcomes may be undeserved. If we assume this to be the case, the question then arises, are undeserved market outcomes are unjust? Any reasonable answer to this question requires a coherent idea of justice within which we could determine what is deserved and undeserved, and judge the justice of those deserts. In the interest of space, this essay will briefly describe two essential notions of justice, and rule one of them out as the less coherent of the two. Once an acceptable sense of justice is established, I will then proceed to render a decision on the question of desert and justice in the market.

Broadly speaking, there are two sense of justice that underlie discussions of the market and its moral character. The first, is the sense of the “right ordering” of the universe and its contents. This could be thought of as the Platonic sense of justice[^1], wherein individuals are incomplete component parts of a harmonious whole into which they fit. By their particular properties, individuals are sorted into a hierarchy of roles that are deserving of certain benefits and obliged to certain duties. The just society, on this view, is one in which all men properly assume the role they’ve been assigned on account of their properties, and carry out duties and receive benefits according to the divine justice that imposed the right order in the first place. Thus, any benefit received or duty executed that violated this preordained order, would constitute an undeserved outcome, which would be unjust by definition. The second sense of justice is found in the character of particular relations between individuals. On this conception, the hierarchy one finds oneself a part of is less important than the awareness of the value present in any given exchange between oneself and others. This sense of justice could be thought of as roughly Aristotelian[^2]; what matters is correct proportion of reciprocity in exchange. The just relationship is one in which participants owe to each other roughly equal proportions of good or evil, to the extent that they have received the same. In such a regime, an “undeserved outcome” would be any exchange in which the outcome of the exchange resulted in an imbalanced ratio of cost and benefit. If the numerator and denominator of the ratio representing the reciprocity involved in the exchange did not resolve to 1, an injustice has occurred, and in such a situation, both parties will have experienced an undeserved outcome: one will have benefited undeservedly, the other, suffered undeservedly.

F.A . Hayek[^3] denies that the first sense of justice could be legitimate. He argues from a strictly descriptive view of social organization. He says that any attempt to attribute a moral valence to one particular ordering of society over another would be incoherent because there could be no sense in which any given pattern is “right” or “wrong”. Think of a flock of starlings, swirling and shifting in various shapes and formations across an evening sky. At best, all we could do is describe the collective shape and patterns of motion mathematically. We might even be able to predict their patterns, given enough information about the biology of starlings, and the physics of flight. But what we could not reasonably say, is that any given location in the sky, any given distribution of birds, or any given pattern of flight of the flock, is the “correct” one. This is a problem as old as Plato’s dialogues. To what are we referring, when we declare any particular ordering of society (or any particular distribution of goods in the market) to be just or unjust? How could this be anything other than an an arbitrary preference (thus, lacking the moral authority to justify the imposition of force against anyone in order to impose it)? Resolving the Parmenidean problem is beyond the scope of this essay, but it does provide enough justification to call into question the coherence of justice as a correctly “patterned distribution” (of men or goods or both). Hayek’s criticism of this first sense of justice is evocative of Robert Nozick[^4]. However, it is a much stronger claim than Nozick’s. He also rejected “patterned distributions”, but not on Humean grounds. Rather, Nozick takes the moral valence of the principles of liberty and equality as John Rawls presents them in his Theory of Justice, but points to an inconsistency present in Rawls’ theory, as a result of assigning these values. Rawls holds liberty up, on the one hand, as a “lexical” principle against which all other principles are to be subordinated. On the other hand, he thinks that forced redistributions (antithetical to liberty) are justifiable in order to satisfy the patterned distributions mandated by the limits of his Difference Principle. Rawls never sufficiently reconciles this tension, and the best his defenders can offer is to say that practical limitations at the boundaries of any principle will necessarily require the principle to be sacrificed sometimes. This is hardly consolation, when the principle in question is itself liberty. So, even if we could argue that Hayek was making too strong a claim, it still seems that the first sense of justice is untenable from the point of view of Nozick.

The first sense of justice having been collapsed for lack coherence, we are thus left with the second sense of justice as a sort of balance of accounts between individuals. Here, we diverge from Aristotle in that the right proportions are not determined relative to an official judgment of contributions made to the public weal (as in, for example, the case of the honour earned by an Athenian juryman or soldier), but rather relative to a spontaneously emergent attribution of material value, determined dynamically, Hayek (and Adam Smith) argues, by the aggregate expression of the preferences of large numbers of individuals acting freely in the market. In simple terms, this means that if I decide I want a new pair of sneakers, I must be willing to pay a price somewhere in the range of prices set by the various competitors offering sneakers for sale. The exchange of a satisfactory pair of sneakers for the requisite sum of money, is a just market outcome, insofar as both parties are satisfied with the value received during the exchange. It is clear from this simple illustration that an undeserved outcome would be nearly synonymous with an unjust outcome, because there could be no situation in which one party believed his half of a bargain was undeserved, without it also constituting an obviously unjust imbalance of accounts – for example, if I had stolen the sneakers, or if the retailer had taken my payment and then refused to provide the shoes. On this view, it is difficult to see how any undeserved outcomes could be considered just. As Hayek puts it in Law, Legislation, and Liberty, “competitive prices arrived at without fraud, monopoly, and violence, are all that justice require[s]… it is only ‘the way in which competition is carried out, not its results, that can be judged just or unjust…” (pg. 236) Even in cases of charity, gift-giving, and inheritance, there is an exchange of value taking place. So, even if the kinds of value differ, it could be argued that the partners in the exchange have at least judged the values traded of like degree. All undeserved outcomes, then, would seem to already fall under the rubric of criminal activity: theft, fraud, or property destruction, which are obviously unjust.

The answer to our original question, then, is an emphatic, ‘yes’. On both the defeated form of justice, and the one we’ve settled with here, undeserved market outcomes are indeed unjust. In fact, it seems that justice and desert are at least generally co-extensive. What this investigation strongly suggests, but only addresses in passing, is the fact that our concept of desert is heavily dependent upon the moral ontology underlying our understanding a just ordering of society. Though Aristotle’s analysis of justice is individualistic in one sense, he still takes it to be the case that some objective hierarchy conditions how judgments of value and desert are made. Hayek, on the other hand, comes at the question from a position of the economists’ moral skepticism. Value is emergent rather than imminent, for him. So, justice is emergent as well. For others, certain fundamental values (such as Nozick’s liberty, or Williams’ equality[^5]) stand as the axiomatic basis (real or otherwise) of a foundational ethic that derives desert as a consequence of the implications of those values. Within this landscape of moral foundations, the market must somehow be accounted for. The way in which we characterize the market and its inevitable outcomes, therefore, is going to be conditioned heavily by the concept of justice that arises out of our moral milieu. This essay has offered one rough, simple introduction into how that might be done.

```[Imported from exitingthecave.com on 29 November 2021]```


[^1]: Plato, [The Republic](https://www.gutenberg.org/files/1497/1497-h/1497-h.htm) [↩](https://exitingthecave.com/the-justice-of-market-outcomes-an-exploration-of-desert/#fnref-1)
[^2]: Aristotle, [Nicomachean Ethics, Book V](https://oll.libertyfund.org/titles/903#lf0328_label_230) [↩](https://exitingthecave.com/the-justice-of-market-outcomes-an-exploration-of-desert/#fnref-2)
[^3]: F. A. Hayek, [Law, Legislation, and Liberty, Volume II](https://www.press.uchicago.edu/ucp/books/book/chicago/L/bo5970048.html) [↩](https://exitingthecave.com/the-justice-of-market-outcomes-an-exploration-of-desert/#fnref-3)
[^4]: Robert Nozick, [Anarchy, State, and Utopia, Part II](https://archive.org/stream/0001AnarchyStateAndUtopia/0001_anarchy_state_and_utopia_djvu.txt) [↩](https://exitingthecave.com/the-justice-of-market-outcomes-an-exploration-of-desert/#fnref-4)
[^5]: Bernard Williams [Problems of the Self, Chapter 14, The Idea of Equality](https://exitingthecave.com/wp-content/uploads/2019/12/2f88c-bernard_williams_-_the_idea_of_equality.pdf) [↩](https://exitingthecave.com/the-justice-of-market-outcomes-an-exploration-of-desert/#fnref-5)

